@@ -37,10 +37,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "15.0.2";
+        "15";
 
     private static final String java_version_date =
-        "2021-01-19";
+        "2020-09-15";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -48,16 +48,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "15.0.2+7";
+        "15+36";
 
     private static final String VERSION_NUMBER =
-        "15.0.2";
+        "15";
 
     private static final String VERSION_SPECIFICATION =
         "15";
 
     private static final String VERSION_BUILD =
-        "7";
+        "36";
 
     private static final String VERSION_PRE =
         "";
